@@ -20,6 +20,24 @@ from .shell import run_shell_command
 logger = logging.getLogger(__name__)
 
 
+def subset_validator(allowed):
+    """Create a validator that ensures a list is a subset of allowed values."""
+
+    def validate_subset(_instance, attribute, value):
+        """
+        Validate that value is a subset of allowed values.
+        """
+        value = convert_list(value)
+        bad_values = set(value) - set(allowed)
+        if bad_values:
+            raise ValueError(
+                f"{attribute.name!r} must be chosen from: {', '.join(allowed)}."
+                + f" {', '.join(map(repr, bad_values))} are not allowed."
+            )
+
+    return validate_subset
+
+
 DEFAULT_FORMAT = "rst"
 DEFAULT_CHANGELOG = "CHANGELOG.${config:format}"
 
@@ -60,6 +78,22 @@ class _Options:
         },
     )
 
+    fragment_name_fields = attr.ib(
+        type=list,
+        default=["created", "author", "branch"],
+        validator=attr.validators.optional(  # type: ignore[arg-type]
+            subset_validator(["created", "author", "branch"])
+        ),
+        metadata={
+            "doc": """\
+                The components to use when making new fragment file names.
+                "created" is a timestamp, "author" is the user nick, and
+                "branch" is the current Git branch name if it isn't one of the
+                main branch names.
+                """,
+        },
+    )
+
     # The categories for changelog fragments. Can be empty for no
     # categorization.
     categories = attr.ib(
@@ -144,6 +178,45 @@ class _Options:
         },
     )
 
+    md_setext_chars = attr.ib(
+        type=str,
+        default="",
+        validator=attr.validators.matches_re(r"^$|\S\S"),
+        metadata={
+            "doc": """\
+                Two characters: for Markdown changelog files, these enable
+                setext-style underlined headings if set. The first is for the
+                heading for each changelog entry, the second is for the category
+                sections within the entry. Use "=-" for standard formatting.
+                """,
+            "doc_default": "(empty)",
+        },
+    )
+
+    md_html_anchors = attr.ib(
+        type=bool,
+        default=True,
+        converter=attr.converters.to_bool,
+        metadata={
+            "doc": """\
+                If true, Markdown sections will have HTML anchors added
+                for precise linking.
+                """,
+        },
+    )
+
+    compact_fragments = attr.ib(
+        type=bool,
+        default=False,
+        converter=attr.converters.to_bool,
+        metadata={
+            "doc": """\
+                If true, fragments will be concatenated without blank lines
+                between them, allowing for compact bullet lists.
+                """,
+        },
+    )
+
     # The name of the template for new fragments.
     new_fragment_template = attr.ib(
         type=str,
@@ -291,9 +364,8 @@ class Config:
         attrdef = fields[name]
         value = getattr(self._options, name)
         if attrdef.type is list:
-            if isinstance(value, str):
-                value = convert_list(value)
-        else:
+            value = convert_list(value)
+        elif isinstance(value, str):
             try:
                 value = self.resolve_value(value)
             except ScrivException as se:
@@ -304,7 +376,7 @@ class Config:
         return value
 
     @classmethod
-    def read(cls) -> Config:
+    def read(cls, file_name: str | None = None) -> Config:
         """
         Read the configuration to use.
 
@@ -316,12 +388,15 @@ class Config:
 
         """
         config = cls(post_create_=False)
-        config.read_one_config("setup.cfg")
-        config.read_one_config("tox.ini")
-        config.read_one_toml("pyproject.toml")
-        config.read_one_config(
-            str(Path(config.fragment_directory) / "scriv.ini")
-        )
+        if file_name is not None:
+            config.read_one_config(file_name)
+        else:
+            config.read_one_config("setup.cfg")
+            config.read_one_config("tox.ini")
+            config.read_one_toml("pyproject.toml")
+            config.read_one_config(
+                str(Path(config.fragment_directory) / "scriv.ini")
+            )
         with validator_exceptions():
             attr.validate(config._options)
         config._options.post_create()
@@ -347,7 +422,7 @@ class Config:
         """
         logger.debug(f"Looking for config file {configfile}")
         parser = configparser.ConfigParser()
-        files_read = parser.read(configfile)
+        files_read = parser.read(configfile, encoding="utf-8")
         if not files_read:
             logger.debug(f"{configfile} doesn't exist")
             return
@@ -485,13 +560,16 @@ class Config:
         return value
 
 
-def convert_list(val: str) -> list[str]:
+def convert_list(val: str | list[str]) -> list[str]:
     """
     Convert a string value from a config into a list of strings.
 
     Elements can be separated by commas or newlines.
     """
-    vals = re.split(r"[\n,]", val)
-    vals = [v.strip() for v in vals]
-    vals = [v for v in vals if v]
-    return vals
+    if isinstance(val, str):
+        vals = re.split(r"[\n,]", val)
+        vals = [v.strip() for v in vals]
+        vals = [v for v in vals if v]
+        return vals
+    else:
+        return val
