@@ -2,7 +2,6 @@
 
 import logging
 import sys
-from typing import Optional
 
 import click
 
@@ -23,7 +22,12 @@ logger = logging.getLogger(__name__)
     help="Open the created file in your text editor.",
 )
 @scriv_command
-def create(add: Optional[bool], edit: Optional[bool]) -> None:
+def create(
+    *,
+    add: bool | None,
+    edit: bool | None,
+    config_file: str | None,
+) -> None:
     """
     Create a new changelog fragment.
     """
@@ -31,8 +35,7 @@ def create(add: Optional[bool], edit: Optional[bool]) -> None:
         add = git_config_bool("scriv.create.add")
     if edit is None:
         edit = git_config_bool("scriv.create.edit")
-
-    scriv = Scriv()
+    scriv = Scriv(config_file=config_file)
     frag = scriv.new_fragment()
     file_path = frag.path
     if not file_path.parent.exists():
