@@ -3,7 +3,6 @@
 import os
 import re
 import tempfile
-from typing import Optional
 
 from .exceptions import ScrivException
 from .format import FormatTools, SectionDict
@@ -52,7 +51,8 @@ class RstTools(FormatTools):
         return bool(re.search(r"^.. _[-.\w]+:$", line))
 
     def parse_text(
-        self, text: str
+        self,
+        text: str,
     ) -> SectionDict:  # noqa: D102 (inherited docstring)
         # Parse a very restricted subset of rst.
         lines = text.splitlines()
@@ -117,7 +117,9 @@ class RstTools(FormatTools):
         return sections
 
     def format_header(
-        self, text: str, anchor: Optional[str] = None
+        self,
+        text: str,
+        anchor: str | None = None,
     ) -> str:  # noqa: D102 (inherited docstring)
         header = "\n"
         if anchor:
@@ -125,22 +127,26 @@ class RstTools(FormatTools):
         header += (
             text + "\n" + self.config.rst_header_chars[0] * len(text) + "\n"
         )
-        return header
+        return header  # type: ignore[no-any-return]
 
     def format_sections(
-        self, sections: SectionDict
+        self,
+        sections: SectionDict,
     ) -> str:  # noqa: D102 (inherited docstring)
-        lines = []
+        lines = [""]
         for section, paragraphs in sections.items():
             if section:
-                lines.append("")
                 lines.append(section)
                 lines.append(self.config.rst_header_chars[1] * len(section))
-            for paragraph in paragraphs:
                 lines.append("")
+            for paragraph in paragraphs:
                 lines.append(paragraph)
+                if not self.config.compact_fragments:
+                    lines.append("")
+            if self.config.compact_fragments and lines[-1] != "":
+                lines.append("")
 
-        return "\n".join(lines) + "\n"
+        return "\n".join(lines)
 
     def convert_to_markdown(
         self, text: str, name: str = "", fail_if_warn: bool = False
