@@ -7,7 +7,6 @@ import re
 import textwrap
 from collections.abc import Iterable
 from pathlib import Path
-from typing import Optional
 
 import jinja2
 
@@ -21,10 +20,15 @@ from .util import order_dict
 class Scriv:
     """Public API to the scriv application."""
 
-    def __init__(self, *, config: Optional[Config] = None):
+    def __init__(
+        self,
+        *,
+        config: Config | None = None,
+        config_file: str | None = None,
+    ):
         """Create a new Scriv."""
         if config is None:
-            self.config = Config.read()
+            self.config = Config.read(config_file)
         else:
             self.config = config
 
@@ -77,13 +81,19 @@ def _new_fragment_path(config: Config) -> Path:
     Return the file path for a new fragment.
     """
     now = datetime.datetime.now()
-    file_name = f"{now:%Y%m%d_%H%M%S}_{user_nick()}"
     branch_name = current_branch_name()
     if branch_name and branch_name not in config.main_branches:
         branch_name = branch_name.rpartition("/")[-1]
         branch_name = re.sub(r"[^a-zA-Z0-9_]", "_", branch_name)
-        file_name += f"_{branch_name}"
-    file_name += f".{config.format}"
+    else:
+        branch_name = ""
+    parts = {
+        "created": f"{now:%Y%m%d_%H%M%S}",
+        "author": user_nick(),
+        "branch": branch_name,
+    }
+    file_name_values = [parts[p] for p in config.fragment_name_fields]
+    file_name = "_".join(v for v in file_name_values if v) + f".{config.format}"
     file_path = Path(config.fragment_directory) / file_name
     return file_path
 
