@@ -199,9 +199,10 @@ def test_parse_text(text, parsed):
 
 
 @pytest.mark.parametrize(
-    "sections, expected",
+    "config_kwargs, sections, expected",
     [
         pytest.param(
+            {"md_header_level": "2"},
             [
                 (
                     "Added",
@@ -235,6 +236,7 @@ def test_parse_text(text, parsed):
             id="one",
         ),
         pytest.param(
+            {"md_header_level": 2},
             [
                 (
                     None,
@@ -255,11 +257,79 @@ def test_parse_text(text, parsed):
             """,
             id="two",
         ),
+        pytest.param(
+            {"md_setext_chars": "=-"},
+            [
+                (
+                    "Added",
+                    [
+                        "- This thing was added.\n  And we liked it.",
+                        "- Also added\n  this thing\n  that is very important.",
+                    ],
+                ),
+                (
+                    "Bugs Fixed",
+                    ["- This thing was fixed.", "- Another thing was fixed."],
+                ),
+            ],
+            """\
+
+            Added
+            -----
+
+            - This thing was added.
+              And we liked it.
+
+            - Also added
+              this thing
+              that is very important.
+
+            Bugs Fixed
+            ----------
+
+            - This thing was fixed.
+
+            - Another thing was fixed.
+            """,
+            id="one",
+        ),
+        pytest.param(
+            {"md_header_level": "2", "compact_fragments": True},
+            [
+                (
+                    "Added",
+                    [
+                        "- This thing was added.\n  And we liked it.",
+                        "- Also added\n  this thing\n  that is very important.",
+                    ],
+                ),
+                (
+                    "Fixed",
+                    ["- This thing was fixed.", "- Another thing was fixed."],
+                ),
+            ],
+            """\
+
+            ### Added
+
+            - This thing was added.
+              And we liked it.
+            - Also added
+              this thing
+              that is very important.
+
+            ### Fixed
+
+            - This thing was fixed.
+            - Another thing was fixed.
+            """,
+            id="compact",
+        ),
     ],
 )
-def test_format_sections(sections, expected):
+def test_format_sections(config_kwargs, sections, expected):
     sections = collections.OrderedDict(sections)
-    actual = MdTools(Config(md_header_level="2")).format_sections(sections)
+    actual = MdTools(Config(**config_kwargs)).format_sections(sections)
     assert actual == textwrap.dedent(expected)
 
 
@@ -268,12 +338,24 @@ def test_format_sections(sections, expected):
     [
         ({}, "2020-07-26", {}, "\n# 2020-07-26\n"),
         ({"md_header_level": "3"}, "2020-07-26", {}, "\n### 2020-07-26\n"),
+        (
+            {"md_setext_chars": "*#"},
+            "2020-07-26",
+            {},
+            "\n2020-07-26\n**********\n",
+        ),
         (
             {},
             "2022-04-03",
             {"anchor": "here"},
             "\n<a id='here'></a>\n# 2022-04-03\n",
         ),
+        (
+            {"md_html_anchors": False},
+            "2022-04-03",
+            {"anchor": "here"},
+            "\n# 2022-04-03\n",
+        ),
     ],
 )
 def test_format_header(config_kwargs, text, fh_kwargs, result):
